use crate::db::server_config::ServerConfig;
use serde::{Deserialize, Serialize};
use tracing::{info, instrument};

#[derive(Serialize, Deserialize, Debug, Clone)]
pub enum AddAdminConfigError {
    UnknownError(String),
}

#[instrument(level = "info")]
pub async fn admin_role(
    server_id: u64,
    role_add_id: Option<u64>,
    role_remove_id: Option<u64>,
) -> Result<(), AddAdminConfigError> {
    let server_config = match ServerConfig::find_by_server_id(&server_id).await {
        Ok(server_config) => server_config,
        Err(err) => {
            tracing::error!(error = err.to_string(), "Error finding server config");
            return Err(AddAdminConfigError::UnknownError(
                "Error finding server config".to_string(),
            ));
        }
    };
    if let Some(mut config) = server_config {
        if let Some(role_id) = role_add_id {
            info!(id = role_id, "Adding role to admin role");
            config.admin_role.push(role_id);
        }
        if let Some(role_id) = role_remove_id {
            info!(id = role_id, "Remove role to admin role");
            config.admin_role.retain(|&x| x != role_id);
        }
        match config.update().await {
            Ok(_) => {}
            Err(err) => {
                tracing::error!(error = err.to_string(), "Error updating server config");
                return Err(AddAdminConfigError::UnknownError(
                    "Error updating server config".to_string(),
                ));
            }
        }
    }
    Ok(())
}
