use serde::{Deserialize, Serialize};
use tracing::instrument;

use crate::db::server_config::ServerConfig;

#[derive(Serialize, Deserialize, Debug, Clone)]
pub enum CheckIfServerEnableError {
    UnknownError(String),
}

#[instrument(level = "info")]
pub async fn check_if_server_enable(
    server_id: u64,
) -> Result<(bool, Option<ServerConfig>), CheckIfServerEnableError> {
    let server_config =
        match crate::db::server_config::ServerConfig::find_by_server_id(&server_id).await {
            Ok(server_config) => server_config,
            Err(err) => {
                tracing::error!(error = err.to_string(), "Error finding server config");
                return Err(CheckIfServerEnableError::UnknownError(
                    "Error finding server config".to_string(),
                ));
            }
        };
    match server_config {
        None => {
            tracing::info!("Server config not found");
            return Err(CheckIfServerEnableError::UnknownError(
                "Server config not found".to_string(),
            ));
        }
        Some(server_config) => Ok((server_config.enable, Some(server_config))),
    }
}
