use crate::config::PersistenceConfig;
use once_cell::sync::Lazy;
use surrealdb::engine::remote::ws::Ws;
use surrealdb::opt::auth::Root;
use surrealdb::{engine::remote::ws::Client, Surreal};

pub static DB: Lazy<Surreal<Client>> = Lazy::new(Surreal::init);

pub async fn init_db(config: PersistenceConfig) -> Result<(), surrealdb::Error> {
    match DB.connect::<Ws>(config.url.as_str()).await {
        Ok(_) => {}
        Err(e) => return Err(e),
    };

    match DB
        .signin(Root {
            username: config.user.as_str(),
            password: config.password.as_str(),
        })
        .await
    {
        Ok(_) => {}
        Err(e) => return Err(e),
    }

    match DB
        .use_ns(config.namespace.as_str())
        .use_db(config.database.as_str())
        .await
    {
        Ok(_) => {}
        Err(e) => return Err(e),
    }

    Ok(())
}
